@@ -29,7 +29,6 @@ use strict;
 use warnings;
 
 require ZoneMinder::Base;
-require Date::Manip;
 require POSIX;
 use ZoneMinder::Config qw(:all);
 use ZoneMinder::Logger qw(:all);
@@ -232,7 +231,7 @@ sub Sql {
                 $value = "'$ZoneMinder::Config::Config{ZM_SERVER_ID}'";
                 # This gets used later, I forget for what
                 $$self{Server} = new ZoneMinder::Server($ZoneMinder::Config::Config{ZM_SERVER_ID});
-              } elsif ( $temp_value eq 'NULL' ) {
+              } elsif ( uc($temp_value) eq 'NULL' ) {
                 $value = $temp_value;
               } else {
                 $value = "'$temp_value'";
@@ -254,7 +253,7 @@ sub Sql {
               }
               $value = "'$temp_value'";
             } elsif ( $term->{attr} eq 'DateTime' or $term->{attr} eq 'StartDateTime' or $term->{attr} eq 'EndDateTime' ) {
-              if ( $temp_value eq 'NULL' ) {
+              if ( uc($temp_value) eq 'NULL' ) {
                 $value = $temp_value;
               } else {
                 $value = DateTimeToSQL($temp_value);
@@ -265,7 +264,7 @@ sub Sql {
                 $value = "'$value'";
               }
             } elsif ( $term->{attr} eq 'Date' or $term->{attr} eq 'StartDate' or $term->{attr} eq 'EndDate' ) {
-              if ( $temp_value eq 'NULL' ) {
+              if ( uc($temp_value) eq 'NULL' ) {
                 $value = $temp_value;
               } elsif ( $temp_value eq 'CURDATE()' or $temp_value eq 'NOW()' ) {
                 $value = 'to_days('.$temp_value.')';
@@ -278,7 +277,7 @@ sub Sql {
                 $value = "to_days( '$value' )";
               }
             } elsif ( $term->{attr} eq 'Time' or $term->{attr} eq 'StartTime' or $term->{attr} eq 'EndTime' ) {
-              if ( $temp_value eq 'NULL' ) {
+              if ( uc($temp_value) eq 'NULL' ) {
                 $value = $temp_value;
               } else {
                 $value = DateTimeToSQL($temp_value);
@@ -361,46 +360,24 @@ sub Sql {
     if ( @auto_terms ) {
       $sql .= ' AND ( '.join(' or ', @auto_terms).' )';
     }
-    if ( !$filter_expr->{sort_field} ) {
-      $filter_expr->{sort_field} = 'StartDateTime';
-      $filter_expr->{sort_asc} = 0;
+    if ($filter_expr->{sort_field}) {
+      my $sort_column = '';
+      if ( $filter_expr->{sort_field} eq 'MonitorName' ) {
+        $sql = 'SELECT E.*, unix_timestamp(E.StartDateTime) as Time, M.Name as MonitorName
+        FROM Events as E INNER JOIN Monitors as M on M.Id = E.MonitorId';
+        $sort_column = 'M.Name';
+      } elsif ( $filter_expr->{sort_field} eq 'StartTime' ) {
+        $sort_column = 'E.StartDateTime';
+      } elsif ( $filter_expr->{sort_field} eq 'EndTime' ) {
+        $sort_column = 'E.EndDateTime';
+      } elsif ( $filter_expr->{sort_field} eq 'Secs' ) {
+        $sort_column = 'E.Length';
+      } else {
+        $sort_column = 'E.'.$filter_expr->{sort_field};
+      }
+      my $sort_order = $filter_expr->{sort_asc} ? 'ASC' : 'DESC';
+      $sql .= ' ORDER BY '.$sort_column.' '.$sort_order;
     }
-    my $sort_column = '';
-    if ( $filter_expr->{sort_field} eq 'Id' ) {
-      $sort_column = 'E.Id';
-    } elsif ( $filter_expr->{sort_field} eq 'MonitorName' ) {
-            $sql = 'SELECT E.*, unix_timestamp(E.StartDateTime) as Time, M.Name as MonitorName
-         FROM Events as E INNER JOIN Monitors as M on M.Id = E.MonitorId';
-      $sort_column = 'M.Name';
-    } elsif ( $filter_expr->{sort_field} eq 'Name' ) {
-      $sort_column = 'E.Name';
-    } elsif ( $filter_expr->{sort_field} eq 'StartDateTime' ) {
-      $sort_column = 'E.StartDateTime';
-    } elsif ( $filter_expr->{sort_field} eq 'StartTime' ) {
-      $sort_column = 'E.StartDateTime';
-    } elsif ( $filter_expr->{sort_field} eq 'EndTime' ) {
-      $sort_column = 'E.EndDateTime';
-    } elsif ( $filter_expr->{sort_field} eq 'EndDateTime' ) {
-      $sort_column = 'E.EndDateTime';
-    } elsif ( $filter_expr->{sort_field} eq 'Secs' ) {
-      $sort_column = 'E.Length';
-    } elsif ( $filter_expr->{sort_field} eq 'Frames' ) {
-      $sort_column = 'E.Frames';
-    } elsif ( $filter_expr->{sort_field} eq 'AlarmFrames' ) {
-      $sort_column = 'E.AlarmFrames';
-    } elsif ( $filter_expr->{sort_field} eq 'TotScore' ) {
-      $sort_column = 'E.TotScore';
-    } elsif ( $filter_expr->{sort_field} eq 'AvgScore' ) {
-      $sort_column = 'E.AvgScore';
-    } elsif ( $filter_expr->{sort_field} eq 'MaxScore' ) {
-      $sort_column = 'E.MaxScore';
-    } elsif ( $filter_expr->{sort_field} eq 'DiskSpace' ) {
-      $sort_column = 'E.DiskSpace';
-    } else {
-      $sort_column = 'E.StartDateTime';
-    }
-    my $sort_order = $filter_expr->{sort_asc} ? 'ASC' : 'DESC';
-    $sql .= ' ORDER BY '.$sort_column.' '.$sort_order;
     if ( $filter_expr->{limit} ) {
       $sql .= ' LIMIT 0,'.$filter_expr->{limit};
     }
@@ -445,6 +422,7 @@ sub getLoad {
 #
 sub strtotime {
   my $dt_str = shift;
+  require Date::Manip;
   return Date::Manip::UnixDate($dt_str, '%s');
 }
 
