@@ -43,21 +43,23 @@ Event::PreAlarmData Event::pre_alarm_data[MAX_PRE_ALARM_FRAMES] = {};
 
 Event::Event(
     Monitor *p_monitor,
+    packetqueue_iterator *p_packetqueue_it,
     struct timeval p_start_time,
     const std::string &p_cause,
     const StringSetMap &p_noteSetMap
     ) :
   id(0),
   monitor(p_monitor),
+  packetqueue_it(p_packetqueue_it),
   start_time(p_start_time),
-  end_time({0,0}),
+  end_time(p_start_time),
   cause(p_cause),
   noteSetMap(p_noteSetMap),
   frames(0),
   alarm_frames(0),
   alarm_frame_written(false),
   tot_score(0),
-  max_score(-1),
+  max_score(0),
   //path(""),
   //snapshit_file(),
   snapshot_file_written(false),
@@ -77,6 +79,7 @@ Event::Event(
   timeval now = {};
   gettimeofday(&now, nullptr);
 
+  packetqueue = monitor->GetPacketQueue();
   if ( !start_time.tv_sec ) {
     Warning("Event has zero time, setting to now");
     start_time = now;
@@ -136,7 +139,14 @@ Event::Event(
 
 Event::~Event() {
   Stop();
-  if (thread_.joinable()) thread_.join();
+
+  if (thread_.joinable()) {
+    Debug(1, "Joining event thread");
+    // Should be.  Issuing the stop and then getting the lock
+    thread_.join();
+  }
+  packetqueue->free_it(packetqueue_it);
+  delete packetqueue_it;
 
   /* Close the video file */
   // We close the videowriter first, because if we finish the event, we might try to view the file, but we aren't done writing it yet.
@@ -225,7 +235,7 @@ bool Event::WriteFrameImage(
   return rc;
 }  // end Event::WriteFrameImage( Image *image, struct timeval timestamp, const char *event_file, bool alarm_frame )
 
-bool Event::WritePacket(const std::shared_ptr<ZMPacket>&packet) {
+bool Event::WritePacket(const std::shared_ptr<ZMPacket>packet) {
   if (videoStore->writePacket(packet) < 0)
     return false;
   return true;
@@ -330,16 +340,7 @@ void Event::updateNotes(const StringSetMap &newNoteSetMap) {
   }  // end if update
 }  // void Event::updateNotes(const StringSetMap &newNoteSetMap)
 
-void Event::AddPacket(const std::shared_ptr<ZMPacket>&packet) {
-  {
-    std::unique_lock<std::mutex> lck(packet_queue_mutex);
-
-    packet_queue.push(std::move(packet));
-  }
-  packet_queue_condition.notify_one();
-}
-
-void Event::AddPacket_(const std::shared_ptr<ZMPacket>&packet) {
+void Event::AddPacket_(const std::shared_ptr<ZMPacket>packet) {
   have_video_keyframe = have_video_keyframe || 
     ( ( packet->codec_type == AVMEDIA_TYPE_VIDEO ) && 
       ( packet->keyframe || monitor->GetOptVideoWriter() == Monitor::ENCODE) );
@@ -715,24 +716,43 @@ void Event::Run() {
 
   // The idea is to process the queue no matter what so that all packets get processed.
   // We only break if the queue is empty
-  while (true) {
-    std::shared_ptr<ZMPacket> packet = nullptr;
-    {
-      std::unique_lock<std::mutex> lck(packet_queue_mutex);
-
-      if (packet_queue.empty()) {
-        if (terminate_ or zm_terminate) break;
-        packet_queue_condition.wait(lck);
-      } 
-
-      if (!packet_queue.empty()) {
-        packet = packet_queue.front();
-        packet_queue.pop();
+  while (!terminate_ and !zm_terminate) {
+    ZMLockedPacket *packet_lock = packetqueue->get_packet_no_wait(packetqueue_it);
+    if (packet_lock) {
+      std::shared_ptr<ZMPacket> packet = packet_lock->packet_;
+      if (!packet->decoded) {
+        delete packet_lock;
+        // Stay behind decoder
+        Microseconds sleep_for = Microseconds(ZM_SAMPLE_RATE);
+        Debug(4, "Sleeping for %" PRId64 "us", int64(sleep_for.count()));
+        std::this_thread::sleep_for(sleep_for);
+        continue;
       }
-    }  // end lock scope
-    if (packet) {
+      packetqueue->increment_it(packetqueue_it);
+
       Debug(1, "Adding packet %d", packet->image_index);
       this->AddPacket_(packet);
-    }
+
+      if (packet->image) {
+        if (monitor->GetOptVideoWriter() == Monitor::PASSTHROUGH) {
+          if (!save_jpegs) {
+            Debug(1, "Deleting image data for %d", packet->image_index);
+            // Don't need raw images anymore
+            delete packet->image;
+            packet->image = nullptr;
+          }
+        }
+        if (packet->analysis_image and !(save_jpegs & 2)) {
+          Debug(1, "Deleting analysis image data for %d", packet->image_index);
+          delete packet->analysis_image;
+          packet->analysis_image = nullptr;
+        }
+      } // end if packet->image
+      Debug(1, "Deleting packet lock");
+      delete packet_lock;
+    } else {
+      if (terminate_ or zm_terminate) return;
+      usleep(10000);
+    } // end if packet_lock
   }  // end while
 }  // end Run()
