@@ -166,11 +166,15 @@ int FFmpeg_Input::Close( ) {
 
 AVFrame *FFmpeg_Input::get_frame(int stream_id) {
   int frameComplete = false;
-  AVPacket packet;
-  av_init_packet(&packet);
+  av_packet_ptr packet{av_packet_alloc()};
+
+  if (!packet) {
+    Error("Unable to allocate packet.");
+    return nullptr;
+  }
 
   while (!frameComplete) {
-    int ret = av_read_frame(input_format_context, &packet);
+    int ret = av_read_frame(input_format_context, packet.get());
     if (ret < 0) {
       if (
           // Check if EOF.
@@ -182,17 +186,18 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id) {
         return nullptr;
       }
       Error("Unable to read packet from stream %d: error %d \"%s\".",
-          packet.stream_index, ret, av_make_error_string(ret).c_str());
+          packet->stream_index, ret, av_make_error_string(ret).c_str());
       return nullptr;
     }
-    ZM_DUMP_STREAM_PACKET(input_format_context->streams[packet.stream_index], packet, "Received packet");
+    ZM_DUMP_STREAM_PACKET(input_format_context->streams[packet->stream_index], packet, "Received packet");
 
-    if ((stream_id >= 0) && (packet.stream_index != stream_id)) {
-      Debug(1,"Packet is not for our stream (%d)", packet.stream_index );
+    av_packet_guard pkt_guard{packet};
+    if ((stream_id >= 0) && (packet->stream_index != stream_id)) {
+      Debug(1,"Packet is not for our stream (%d)", packet->stream_index );
       continue;
     }
 
-    AVCodecContext *context = streams[packet.stream_index].context;
+    AVCodecContext *context = streams[packet->stream_index].context;
 
     if ( frame ) {
       av_frame_free(&frame);
@@ -200,15 +205,14 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id) {
     } else {
       frame = zm_av_frame_alloc();
     }
-    ret = zm_send_packet_receive_frame(context, frame, packet);
+    ret = zm_send_packet_receive_frame(context, frame, *packet);
     if ( ret < 0 ) {
       Error("Unable to decode frame at frame %d: %d %s, continuing",
-          streams[packet.stream_index].frame_count, ret, av_make_error_string(ret).c_str());
-      zm_av_packet_unref(&packet);
+          streams[packet->stream_index].frame_count, ret, av_make_error_string(ret).c_str());
       av_frame_free(&frame);
       continue;
     } else {
-      if (is_video_stream(input_format_context->streams[packet.stream_index])) {
+      if (is_video_stream(input_format_context->streams[packet->stream_index])) {
         zm_dump_video_frame(frame, "resulting video frame");
       } else {
         zm_dump_frame(frame, "resulting frame");
@@ -233,13 +237,12 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id) {
     } else {
       Warning("No timebase set in context!");
     }
-    if (is_video_stream(input_format_context->streams[packet.stream_index])) {
+    if (is_video_stream(input_format_context->streams[packet->stream_index])) {
       zm_dump_video_frame(frame, "resulting video frame");
     } else {
       zm_dump_frame(frame, "resulting frame");
     }
 
-    zm_av_packet_unref(&packet);
   } // end while !frameComplete
   return frame;
 }  // end AVFrame *FFmpeg_Input::get_frame
@@ -300,7 +303,12 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id, double at) {
 	last_seek_request = seek_target;
 
   // Normally it is likely just the next packet. Need a heuristic for seeking, something like duration * keyframe interval
-  if (frame->pts + 10*frame->pkt_duration < seek_target) {
+#if LIBAVCODEC_VERSION_CHECK(60, 3, 0, 3, 0)
+  if (frame->pts + 10*frame->duration < seek_target)
+#else
+  if (frame->pts + 10*frame->pkt_duration < seek_target)
+#endif
+  {
     Debug(1, "Jumping ahead");
     if (( ret = av_seek_frame(input_format_context, stream_id, seek_target,
             AVSEEK_FLAG_FRAME
@@ -313,7 +321,21 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id, double at) {
   }
   // Seeking seems to typically seek to a keyframe, so then we have to decode until we get the frame we want.
   if (frame->pts <= seek_target) {
-    while (frame && (frame->pts + frame->pkt_duration < seek_target)) {
+    Debug(1, "Frame pts %" PRId64 " + duration %" PRId64 "= %" PRId64 " <=? %" PRId64,
+        frame->pts,
+#if LIBAVCODEC_VERSION_CHECK(60, 3, 0, 3, 0)
+        frame->duration, frame->pts + frame->duration,
+#else
+        frame->pkt_duration, frame->pts + frame->pkt_duration,
+#endif
+        seek_target);
+    while (frame && (frame->pts +
+#if LIBAVCODEC_VERSION_CHECK(60, 3, 0, 3, 0)
+          frame->duration
+#else
+          frame->pkt_duration
+#endif
+          < seek_target)) {
       if (is_video_stream(input_format_context->streams[stream_id])) {
         zm_dump_video_frame(frame, "pts <= seek_target");
       } else {
