@@ -41,7 +41,6 @@ class MonitorStream : public StreamBase {
     time_t ttl;
     int playback_buffer;
     bool delayed;
-    int frame_count;
 
   protected:
     bool checkSwapPath(const char *path, bool create_path);
@@ -62,9 +61,9 @@ class MonitorStream : public StreamBase {
       temp_write_index(0),
       ttl(0),
       playback_buffer(0),
-      delayed(false),
-      frame_count(0) {
-    }
+      delayed(false)
+  {}
+
     void setStreamBuffer(int p_playback_buffer) {
       playback_buffer = p_playback_buffer;
     }
