@@ -90,14 +90,16 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
     std::unique_lock<std::mutex> lck(mutex);
     if (deleting or zm_terminate) return false;
 
-    if (!has_out_of_order_packets_ and (add_packet->packet.dts != AV_NOPTS_VALUE)) {
+    if (!has_out_of_order_packets_ and (add_packet->packet->dts != AV_NOPTS_VALUE)) {
       auto rit = pktQueue.rbegin();
       // Find the previous packet for the stream, and check dts
       while (rit != pktQueue.rend()) {
-        if ((*rit)->packet.stream_index == add_packet->packet.stream_index) {
-          if ((*rit)->packet.dts >= add_packet->packet.dts) {
+        std::shared_ptr<ZMPacket> prev_packet = *rit;
+
+        if (prev_packet->packet->stream_index == add_packet->packet->stream_index) {
+          if (prev_packet->packet->dts >= add_packet->packet->dts) {
             Debug(1, "Have out of order packets");
-            ZM_DUMP_PACKET((*rit)->packet, "queued_packet");
+            ZM_DUMP_PACKET(prev_packet->packet, "queued_packet");
             ZM_DUMP_PACKET(add_packet->packet, "add_packet");
             has_out_of_order_packets_ = true;
           }
@@ -106,13 +108,28 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
         rit++;
       }  // end while
     }
+    
+    if (!max_keyframe_interval_ and add_packet->keyframe and (video_stream_id==add_packet->packet->stream_index)) {
+      auto rit = pktQueue.rbegin();
+      int packet_count = 0;
+      while (rit != pktQueue.rend()) {
+        if ((*rit)->packet->stream_index == add_packet->packet->stream_index) {
+          if ((*rit)->keyframe) break;
+          packet_count ++;
+        }
+        ++rit;
+      }
+      Debug(1, "Have keyframe interval: %d", packet_count);
+      max_keyframe_interval_ = packet_count;
+    }
 
     pktQueue.push_back(add_packet);
-    packet_counts[add_packet->packet.stream_index] += 1;
+    packet_counts[add_packet->packet->stream_index] += 1;
     Debug(2, "packet counts for %d is %d",
-        add_packet->packet.stream_index,
-        packet_counts[add_packet->packet.stream_index]);
+        add_packet->packet->stream_index,
+        packet_counts[add_packet->packet->stream_index]);
 
+    /* Any iterators that are pointing to the end will now point to the newly pushed packet */
     for (
         auto iterators_it = iterators.begin();
         iterators_it != iterators.end();
@@ -125,7 +142,7 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
     }  // end foreach iterator
 
     if (
-        (add_packet->packet.stream_index == video_stream_id)
+        (add_packet->packet->stream_index == video_stream_id)
         and
         (max_video_packet_count > 0)
         and
@@ -142,7 +159,7 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
       for (
           // Start at second packet because the first is always a keyframe
           auto it = ++pktQueue.begin();
-          //it != pktQueue.end() and  // can't git end because we added our packet
+          //it != pktQueue.end() and  // can't hit end because we added our packet
           (*it != add_packet) && !(deleting or zm_terminate);
           // iterator is incremented by erase
       ) {
@@ -153,7 +170,7 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
           if (warned_count < 2) {
             warned_count++;
             // Can't delete a locked packet, but can delete one after it.
-            Warning("Found locked packet when trying to free up video packets. This basically means that decoding is not keeping up.");
+            Warning("Found locked packet when trying to free up video packets. This means that decoding is not keeping up.");
           }
           ++it;
           continue;
@@ -176,17 +193,17 @@ bool PacketQueue::queuePacket(std::shared_ptr<ZMPacket> add_packet) {
         zm_packet->notify_all();
 
         it = pktQueue.erase(it);
-        packet_counts[zm_packet->packet.stream_index] -= 1;
+        packet_counts[zm_packet->packet->stream_index] -= 1;
         Debug(1,
             "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
-            zm_packet->packet.stream_index,
+            zm_packet->packet->stream_index,
             zm_packet->image_index,
             zm_packet->keyframe,
             packet_counts[video_stream_id],
             max_video_packet_count,
             pktQueue.size());
 
-        if (zm_packet->packet.stream_index == video_stream_id)
+        if (zm_packet->packet->stream_index == video_stream_id)
           break;
       }  // end while
     } else if (warned_count > 0) {
@@ -215,7 +232,7 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
   if (deleting) return;
 
   if (keep_keyframes and ! (
-        add_packet->packet.stream_index == video_stream_id
+        add_packet->packet->stream_index == video_stream_id
         and
         add_packet->keyframe
         and
@@ -225,7 +242,7 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
         )
      ) {
     Debug(3, "stream index %d ?= video_stream_id %d, keyframe %d, keep_keyframes %d,  counts %d > pre_event_count %d at begin %d",
-        add_packet->packet.stream_index, video_stream_id, add_packet->keyframe, keep_keyframes, packet_counts[video_stream_id], pre_event_video_packet_count, 
+        add_packet->packet->stream_index, video_stream_id, add_packet->keyframe, keep_keyframes, packet_counts[video_stream_id], pre_event_video_packet_count,
         ( *(pktQueue.begin()) != add_packet )
         );
     return;
@@ -238,7 +255,7 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
     packetqueue_iterator it = pktQueue.end();
     --it;
     while (*it != add_packet) {
-      if ((*it)->packet.stream_index == video_stream_id)
+      if ((*it)->packet->stream_index == video_stream_id)
         ++tail_count;
       --it;
     }
@@ -258,10 +275,10 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
       }
 
       pktQueue.pop_front();
-      packet_counts[zm_packet->packet.stream_index] -= 1;
+      packet_counts[zm_packet->packet->stream_index] -= 1;
       Debug(1,
             "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
-            zm_packet->packet.stream_index,
+            zm_packet->packet->stream_index,
             zm_packet->image_index,
             zm_packet->keyframe,
             packet_counts[video_stream_id],
@@ -281,6 +298,8 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
     return;
   }
 
+  int keyframe_interval_count = 1;
+  int video_packets_to_delete = 0;    // This is a count of how many packets we will delete so we know when to stop looking
 
   ZMLockedPacket *lp = new ZMLockedPacket(zm_packet);
   if (!lp->trylock()) {
@@ -288,9 +307,14 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
     delete lp;
     return;
   }  // end if first packet not locked
-     
-  int keyframe_interval_count = 1;
-  int video_packets_to_delete = 0;    // This is a count of how many packets we will delete so we know when to stop looking
+ 
+  if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
+    Debug(3, "Found iterator Counted %d video packets. Which would leave %d in packetqueue tail count is %d",
+        video_packets_to_delete, packet_counts[video_stream_id]-video_packets_to_delete, tail_count);
+    delete lp;
+    return;
+  }
+
   ++it;
   delete lp;
 
@@ -305,17 +329,13 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
     }
     delete lp;
 
-#if 0
-    // There are no threads that follow analysis thread.  So there cannot be an it pointing here
-    // event writing thread technically follows, but packets are copied out of queue
     if (is_there_an_iterator_pointing_to_packet(zm_packet)) {
-      if (pktQueue.begin() == next_front)
-        Warning("Found iterator at beginning of queue. Some thread isn't keeping up");
+      Debug(3, "Found iterator Counted %d video packets. Which would leave %d in packetqueue tail count is %d",
+          video_packets_to_delete, packet_counts[video_stream_id]-video_packets_to_delete, tail_count);
       break;
     }
-#endif
 
-    if (zm_packet->packet.stream_index == video_stream_id) {
+    if (zm_packet->packet->stream_index == video_stream_id) {
       keyframe_interval_count++;
       if (zm_packet->keyframe) {
         Debug(3, "Have a video keyframe so setting next front to it. Keyframe interval so far is %d", keyframe_interval_count);
@@ -349,14 +369,14 @@ void PacketQueue::clearPackets(const std::shared_ptr<ZMPacket> &add_packet) {
 
       Debug(1,
             "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
-            zm_packet->packet.stream_index,
+            zm_packet->packet->stream_index,
             zm_packet->image_index,
             zm_packet->keyframe,
             packet_counts[video_stream_id],
             pre_event_video_packet_count,
             pktQueue.size());
       pktQueue.pop_front();
-      packet_counts[zm_packet->packet.stream_index] -= 1;
+      packet_counts[zm_packet->packet->stream_index] -= 1;
     }
   }  // end if have at least max_video_packet_count video packets remaining
 
@@ -387,13 +407,13 @@ void PacketQueue::clear() {
     lp->lock();
     Debug(1,
         "Deleting a packet with stream index:%d image_index:%d with keyframe:%d, video frames in queue:%d max: %d, queuesize:%zu",
-        packet->packet.stream_index,
+        packet->packet->stream_index,
         packet->image_index,
         packet->keyframe,
         packet_counts[video_stream_id],
         pre_event_video_packet_count,
         pktQueue.size());
-    packet_counts[packet->packet.stream_index] -= 1;
+    packet_counts[packet->packet->stream_index] -= 1;
     pktQueue.pop_front();
     delete lp;
   }
@@ -428,6 +448,32 @@ int PacketQueue::packet_count(int stream_id) {
   return packet_counts[stream_id];
 }  // end int PacketQueue::packet_count(int stream_id)
 
+ZMLockedPacket *PacketQueue::get_packet_no_wait(packetqueue_iterator *it) {
+  if (deleting or zm_terminate)
+    return nullptr;
+
+  Debug(4, "Locking in get_packet using it %p queue end? %d",
+      std::addressof(*it), (*it == pktQueue.end()));
+
+  // scope for lock
+  std::unique_lock<std::mutex> lck(mutex);
+  Debug(4, "Have Lock in get_packet");
+  if ((*it == pktQueue.end()) and !(deleting or zm_terminate)) {
+    Debug(2, "waiting.  Queue size %zu it == end? %d", pktQueue.size(), (*it == pktQueue.end()));
+    condition.wait(lck);
+  }
+  if ((*it == pktQueue.end()) or deleting or zm_terminate) return nullptr;
+
+  std::shared_ptr<ZMPacket> p = *(*it);
+  ZMLockedPacket *lp = new ZMLockedPacket(p);
+  if (lp->trylock()) {
+    Debug(2, "Locked packet %d, unlocking packetqueue mutex", p->image_index);
+    return lp;
+  }
+  delete lp;
+  return nullptr;
+}
+
 // Returns a packet. Packet will be locked
 ZMLockedPacket *PacketQueue::get_packet(packetqueue_iterator *it) {
   if (deleting or zm_terminate)
@@ -551,7 +597,7 @@ bool PacketQueue::increment_it(packetqueue_iterator *it, int stream_id) {
   std::unique_lock<std::mutex> lck(mutex);
   do {
     ++(*it);
-  } while ( (*it != pktQueue.end()) and ( (*(*it))->packet.stream_index != stream_id) );
+  } while ( (*it != pktQueue.end()) and ( (*(*it))->packet->stream_index != stream_id) );
 
   if ( *it != pktQueue.end() ) {
     Debug(2, "Incrementing %p, still not at end, so incrementing", it);
@@ -568,6 +614,7 @@ packetqueue_iterator *PacketQueue::get_event_start_packet_it(
 
   packetqueue_iterator *it = new packetqueue_iterator;
   iterators.push_back(it);
+  Debug(4, "Have event start iterator %p", std::addressof(*it));
 
   *it = snapshot_it;
   std::shared_ptr<ZMPacket> packet = *(*it);
@@ -575,25 +622,18 @@ packetqueue_iterator *PacketQueue::get_event_start_packet_it(
   // Step one count back pre_event_count frames as the minimum
   // Do not assume that snapshot_it is video
   // snapshot it might already point to the beginning
-  if (pre_event_count) {
-    while ((*it) != pktQueue.begin()) {
-      packet = *(*it);
-      /*
-      Debug(1, "Previous packet pre_event_count %d stream_index %d keyframe %d score %d",
-          pre_event_count, packet->packet.stream_index, packet->keyframe, packet->score);
-      ZM_DUMP_PACKET(packet->packet, "");
-      */
-      if (packet->packet.stream_index == video_stream_id) {
-        pre_event_count --;
-        if (!pre_event_count)
-          break;
-      }
-      (*it)--;
-    }
+  while (pre_event_count and ((*it) != pktQueue.begin())) {
+    /*
+    Debug(1, "Previous packet pre_event_count %d stream_index %d keyframe %d score %d",
+        pre_event_count, packet->packet->stream_index, packet->keyframe, packet->score);
+    ZM_DUMP_PACKET(packet->packet, "");
+    */
+    if (packet->packet->stream_index == video_stream_id)
+      pre_event_count --;
+    (*it)--;
     packet = *(*it);
   }
-  // it either points to beginning or we have seen pre_event_count video packets.
-  
+
   if (pre_event_count) {
     if (packet->image_index < (int)pre_event_count) {
       // probably just starting up
@@ -605,17 +645,18 @@ packetqueue_iterator *PacketQueue::get_event_start_packet_it(
     return it;
   } else if (!keep_keyframes) {
     // Are encoding, so don't care about keyframes
+    // We could be pointing to a non-video frame though.  Do we care?
     return it;
   }
 
   while ((*it) != pktQueue.begin()) {
-    packet = *(*it);
     //ZM_DUMP_PACKET(packet->packet, "No keyframe");
-    if ((packet->packet.stream_index == video_stream_id) and packet->keyframe)
+    if ((packet->packet->stream_index == video_stream_id) and packet->keyframe)
       return it; // Success
     --(*it);
+    packet = *(*it);
   }
-  if (!(*(*it))->keyframe) {
+  if (!packet->keyframe) {
     Warning("Hit beginning of packetqueue and packet is not a keyframe. index is %d", packet->image_index);
   }
   return it;
@@ -660,8 +701,8 @@ packetqueue_iterator * PacketQueue::get_video_it(bool wait) {
       return nullptr;
     }
     Debug(1, "Packet keyframe %d for stream %d, so returning the it to it",
-        zm_packet->keyframe, zm_packet->packet.stream_index);
-    if (zm_packet->keyframe and ( zm_packet->packet.stream_index == video_stream_id )) {
+        zm_packet->keyframe, zm_packet->packet->stream_index);
+    if (zm_packet->keyframe and ( zm_packet->packet->stream_index == video_stream_id )) {
       Debug(1, "Found a keyframe for stream %d, so returning the it to it", video_stream_id);
       return it;
     }
@@ -672,6 +713,7 @@ packetqueue_iterator * PacketQueue::get_video_it(bool wait) {
 }  // get video_it
 
 void PacketQueue::free_it(packetqueue_iterator *it) {
+  std::unique_lock<std::mutex> lck(mutex);
   for (
       std::list<packetqueue_iterator *>::iterator iterators_it = iterators.begin();
       iterators_it != iterators.end();
@@ -692,6 +734,7 @@ bool PacketQueue::is_there_an_iterator_pointing_to_packet(const std::shared_ptr<
       ) {
     packetqueue_iterator *iterator_it = *iterators_it;
     if (*iterator_it == pktQueue.end()) {
+      Debug(4, "Checking iterator %p == end", std::addressof(*iterator_it));
       continue;
     }
     Debug(4, "Checking iterator %p == packet ? %d", std::addressof(*iterator_it), ( *(*iterator_it) == zm_packet ));
