@@ -59,6 +59,9 @@ bool StreamBase::loadMonitor(int p_monitor_id) {
   if ( !monitor->connect() ) {
     Error("Unable to connect to monitor id %d for streaming", monitor_id);
     monitor->disconnect();
+    // If we couldn't connect, it might be due to size mismatch in shm. Need to reload
+    if ( !(monitor = Monitor::Load(monitor_id, false, Monitor::QUERY)))
+      Error("Unable to reload monitor id %d for streaming", monitor_id);
     return false;
   }
 
@@ -283,12 +286,14 @@ bool StreamBase::sendTextFrame(const char *frame_text) {
 
     image.EncodeJpeg(buffer, &n_bytes);
 
-    if (0 > fputs("--" BOUNDARY "\r\nContent-Type: image/jpeg\r\n", stdout)) {
-      Debug(1, "Error sending  --" BOUNDARY "\r\nContent-Type: image/jpeg\r\n");
-      return false;
+    if (type == STREAM_JPEG) {
+      if (0 > fputs("--" BOUNDARY "\r\n", stdout)) {
+        Debug(1, "Error sending  --" BOUNDARY "\r\n");
+        return false;
+      }
     }
-    if (0 > fprintf(stdout, "Content-Length: %d\r\n\r\n", n_bytes)) {
-      Debug(1, "Error sending Content-Length: %d\r\n\r\n", n_bytes);
+    if (0 > fprintf(stdout, "Content-Type: image/jpeg\r\nContent-Length: %d\r\n\r\n", n_bytes)) {
+      Debug(1, "Error sending Content-Type: image/jpeg\r\nContent-Length: %d\r\n\r\n", n_bytes);
       return false;
     }
     int rc = fwrite(buffer, n_bytes, 1, stdout);
