@@ -20,8 +20,7 @@
 #ifndef ZM_TIME_H
 #define ZM_TIME_H
 
-#include "zm.h"
-
+#include <zm_logger.h>
 #include <sys/time.h>
 
 // Structure used for storing the results of the subtraction
@@ -76,7 +75,9 @@ struct DeltaTimeval
 #define USEC_PER_SEC 1000000
 #define MSEC_PER_SEC 1000
 
+/*
 extern struct timeval tv;
+*/
 
 inline int tvDiffUsec( struct timeval first, struct timeval last )
 {
@@ -86,7 +87,7 @@ inline int tvDiffUsec( struct timeval first, struct timeval last )
 inline int tvDiffUsec( struct timeval first )
 {
   struct timeval now;
-  gettimeofday( &now, NULL );
+  gettimeofday( &now, nullptr );
   return( tvDiffUsec( first, now ) );
 }
 
@@ -98,7 +99,7 @@ inline int tvDiffMsec( struct timeval first, struct timeval last )
 inline int tvDiffMsec( struct timeval first )
 {
   struct timeval now;
-  gettimeofday( &now, NULL );
+  gettimeofday( &now, nullptr );
   return( tvDiffMsec( first, now ) );
 }
 
@@ -110,7 +111,7 @@ inline double tvDiffSec( struct timeval first, struct timeval last )
 inline double tvDiffSec( struct timeval first )
 {
   struct timeval now;
-  gettimeofday( &now, NULL );
+  gettimeofday( &now, nullptr );
   return( tvDiffSec( first, now ) );
 }
 
@@ -146,7 +147,7 @@ inline int tvEq( struct timeval t1, struct timeval t2 )
 inline struct timeval tvNow( void )
 {
   struct timeval t;
-  gettimeofday( &t, NULL );
+  gettimeofday( &t, nullptr );
   return( t );
 }
 
