@@ -298,33 +298,21 @@ class Filter extends ZM_Object {
   }
 
   public function test_pre_sql_conditions() {
-    if ( !count($this->pre_sql_conditions()) ) {
-      return true;
-    } # end if pre_sql_conditions
-
-    $failed = false;
-    foreach ( $this->pre_sql_conditions() as $term ) {
-      if ( !$term->test() ) {
-        $failed = true;
-        break;
+    if (count($this->pre_sql_conditions())) {
+      foreach ($this->pre_sql_conditions() as $term) {
+        if (!$term->test()) return false;
       }
-    }
-    return $failed;
+    } # end if pre_sql_conditions
+    return true;
   }
 
   public function test_post_sql_conditions($event) {
-    if ( !count($this->post_sql_conditions()) ) {
-      return true;
-    } # end if pre_sql_conditions
-
-    $failed = true;
-    foreach ( $this->post_sql_conditions() as $term ) {
-      if ( !$term->test($event) ) {
-        $failed = false;
-        break;
+    if (count($this->post_sql_conditions())) {
+      foreach ($this->post_sql_conditions() as $term) {
+        if (!$term->test($event)) return false;
       }
-    }
-    return $failed;
+    } # end if pre_sql_conditions
+    return true;
   }
 
   function tree() {
@@ -575,17 +563,17 @@ class Filter extends ZM_Object {
           case 'EndDateTime':
           case 'StartDateTime':
             if ( $value_upper != 'NULL' )
-              $value = "'".strftime(STRF_FMT_DATETIME_DB, strtotime($value))."'";
+              $value = "'".date(STRF_FMT_DATETIME_DB, strtotime($value))."'";
             break;
           case 'Date':
           case 'EndDate':
           case 'StartDate':
-            $value = 'to_days(\''.strftime(STRF_FMT_DATETIME_DB, strtotime($value)).'\')';
+            $value = 'to_days(\''.date(STRF_FMT_DATETIME_DB, strtotime($value)).'\')';
             break;
           case 'Time':
           case 'EndTime':
           case 'StartTime':
-            $value = 'extract(hour_second from \''.strftime(STRF_FMT_DATETIME_DB, strtotime($value)).'\')';
+            $value = 'extract(hour_second from \''.date(STRF_FMT_DATETIME_DB, strtotime($value)).'\')';
             break;
           default :
             if ( $value_upper != 'NULL' )
