@@ -42,7 +42,27 @@ if ( false ) {
   ob_end_clean();
 }
 
+global $dateFormatter;
+global $dateTimeFormatter;
+global $timeFormatter;
+$dateFormatter = new IntlDateFormatter(null, IntlDateFormatter::SHORT, IntlDateFormatter::NONE);
+$dateTimeFormatter = new IntlDateFormatter(null, IntlDateFormatter::SHORT, IntlDateFormatter::LONG);
+$timeFormatter = new IntlDateFormatter(null, IntlDateFormatter::NONE, IntlDateFormatter::LONG);
 require_once('includes/config.php');
+if (ZM_LOCALE_DEFAULT) {
+  $dateFormatter = new IntlDateFormatter(ZM_LOCALE_DEFAULT, IntlDateFormatter::SHORT, IntlDateFormatter::NONE);
+  $dateTimeFormatter = new IntlDateFormatter(ZM_LOCALE_DEFAULT, IntlDateFormatter::SHORT, IntlDateFormatter::LONG);
+  $timeFormatter = new IntlDateFormatter(ZM_LOCALE_DEFAULT, IntlDateFormatter::NONE, IntlDateFormatter::LONG);
+}
+if (ZM_DATE_FORMAT_PATTERN) {
+  $dateFormatter->setPatter(ZM_DATE_FORMAT_PATTERN);
+}
+if (ZM_DATETIME_FORMAT_PATTERN) {
+  $dateTimeFormatter->setPattern(ZM_DATETIME_FORMAT_PATTERN);
+}
+if (ZM_TIME_FORMAT_PATTERN) {
+  $timeFormatter->setPattern(ZM_TIME_FORMAT_PATTERN);
+}
 require_once('includes/session.php');
 require_once('includes/logger.php');
 require_once('includes/Server.php');
@@ -118,6 +138,10 @@ if (!is_dir("skins/$skin/css/$css")) {
     if (!in_array($css, $css_skins)) {
       ZM\Error("Invalid skin css '$css' setting to " . $css_skins[0]);
       $css = $css_skins[0];
+      if (isset($_COOKIE['zmCSS'])) {
+        unset($_COOKIE['zmCSS']);
+        setcookie('zmCSS', '', time() - 3600);
+      }
     } else {
       $css = '';
     }
@@ -196,7 +220,7 @@ foreach ( getSkinIncludes('skin.php') as $includeFile ) {
 if (isset($_POST['action'])) {
   # Actions can only be performed on POST because we don't check csrf on GETs.
   $action = detaintPath($_POST['action']);
-} else if (isset($_REQUEST['action']) and $_REQUEST['action']) {
+} else if (isset($_REQUEST['action']) and $_REQUEST['action'] and empty($_REQUEST['request'])) {
   ZM\Error('actions can no longer be performed without POST. Requested: '.$_REQUEST['action']. ' for ' .$view);
 }
 
@@ -277,8 +301,11 @@ if ( $includeFiles = getSkinIncludes('views/'.$view.'.php', true, true) ) {
   ob_start();
   CSPHeaders($view, $cspNonce);
   foreach ( $includeFiles as $includeFile ) {
-    if (!file_exists($includeFile))
-      ZM\Fatal("View '$view' does not exist");
+    if (!file_exists($includeFile)) {
+      ZM\Error("View '$view' does not exist, redirecting to console");
+      header('Location: ?view=console');
+      return;
+    }
     require_once $includeFile;
   }
   // If the view overrides $view to 'error', and the user is not logged in, then the
