@@ -38,7 +38,8 @@ $fid = 0;
 if ( isset($_REQUEST['Id']) and $_REQUEST['Id'] ) {
   $fid = validInt($_REQUEST['Id']);
 } else if ( isset($_REQUEST['filter']) and isset($_REQUEST['filter']['Id']) ) {
-  $fid = validInt($_REQUEST['filter']['Id']);
+  # $_REQUEST['filter']['Id'] get used later in populating filter object, so need to sanitise it
+  $fid = $_REQUEST['filter']['Id'] = validInt($_REQUEST['filter']['Id']);
 }
 $filter = null;
 foreach ( ZM\Filter::find(null,array('order'=>'lower(Name)')) as $Filter ) {
@@ -367,6 +368,7 @@ for ( $i=0; $i < count($terms); $i++ ) {
                 <?php
 # Note: The keys need to be actual column names
 $sort_fields = array(
+    ''              => translate('None'),
     'Id'            => translate('AttrId'),
     'Name'          => translate('AttrName'),
     'Cause'         => translate('AttrCause'),
@@ -374,6 +376,7 @@ $sort_fields = array(
     'Notes'         => translate('AttrNotes'),
     'MonitorName'   => translate('AttrMonitorName'),
     'StartDateTime' => translate('AttrStartDateTime'),
+    'EndDateTime'   => translate('AttrEndDateTime'),
     'Length'        => translate('AttrDuration'),
     'Frames'        => translate('AttrFrames'),
     'AlarmFrames'   => translate('AttrAlarmFrames'),
