@@ -15,7 +15,7 @@ var record_event_stats = <?php echo ZM_RECORD_EVENT_STATS ?>;
 var alarmFrame = <?php echo $alarmFrame ?>;
 
 var statHeaderStrings = {
-    Id: '<?php echo translate('EventId') ?>',
+    EventId: '<?php echo translate('EventId') ?>',
     FrameId: '<?php echo translate('FrameId') ?>',
     ZoneName: '<?php echo translate('Zone') ?>',
     PixelDiff: '<?php echo translate('PixelDiff') ?>',
