@@ -3,7 +3,6 @@ function submitCamera( element ) {
   form.target = self.name;
   form.view.value = 'monitor';
   form.submit();
-  closeWindow.delay( 250 );
 }
 
 function gotoStep1( element ) {
@@ -33,3 +32,7 @@ function configureButtons(element) {
     form.saveBtn.disabled = (form.probe.selectedIndex==0);
   }
 }
+
+function changeInterface(element) {
+  gotoStep1(element);
+}
