@@ -266,7 +266,7 @@ function highlightOn(index) {
 
 function highlightOff(index) {
   row = $j('#row'+index);
-  if ( row ) {
+  if ( row.length ) {
     row.removeClass('highlight');
   } else {
     console.log("No row for index " + index);
@@ -323,7 +323,7 @@ function constrainValue(value, loVal, hiVal) {
 
 function updateActivePoint(index) {
   var point = $j('#point'+index);
-  var imageFrame = document.getElementById('imageFrame');
+  var imageFrame = document.getElementById('imageFrame'+monitorId);
   var style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
   var padding_left = parseInt(style.paddingLeft);
   var padding_top = parseInt(style.paddingTop);
@@ -378,9 +378,9 @@ function limitPointValue(point, loVal, hiVal) {
 }
 
 function updateArea( ) {
-  area = Polygon_calcArea(zone['Points']);
+  const area = Polygon_calcArea(zone['Points']);
   zone.Area = area;
-  var form = document.getElementById('zoneForm');
+  const form = document.getElementById('zoneForm');
   form.elements['newZone[Area]'].value = area;
   if ( form.elements['newZone[Units]'].value == 'Percent' ) {
     form.elements['newZone[TempArea]'].value = Math.round( area/monitorArea*100 );
@@ -392,30 +392,40 @@ function updateArea( ) {
 }
 
 function updateX(input) {
-  index = input.getAttribute('data-point-index');
+  const index = input.getAttribute('data-point-index');
 
   limitPointValue(input, 0, maxX);
 
-  var point = $j('#point'+index);
-  var x = input.value;
+  const point = $j('#point'+index);
+  const x = parseInt(input.value);
+  const imageFrame = document.getElementById('imageFrame'+monitorId);
+  const style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
+  const padding_left = parseInt(style.paddingLeft);
+  const padding_right = parseInt(style.paddingRight);
+  const scale = (imageFrame.clientWidth - ( padding_left + padding_right )) / maxX;
 
-  point.css('left', x+'px');
+  point.css('left', parseInt(x*scale)+'px');
   zone['Points'][index].x = x;
-  var Point = document.getElementById('zonePoly').points.getItem(index);
+  const Point = document.getElementById('zonePoly').points.getItem(index);
   Point.x = x;
   updateArea();
 }
 
 function updateY(input) {
-  index = input.getAttribute('data-point-index');
+  const index = input.getAttribute('data-point-index');
   limitPointValue(input, 0, maxY);
 
-  var point = $j('#point'+index);
-  var y = input.value;
+  const point = $j('#point'+index);
+  const y = input.value;
+  const imageFrame = document.getElementById('imageFrame'+monitorId);
+  const style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
+  const padding_left = parseInt(style.paddingLeft);
+  const padding_right = parseInt(style.paddingRight);
+  const scale = (imageFrame.clientWidth - ( padding_left + padding_right )) / maxX;
 
-  point.css('top', y+'px');
+  point.css('top', parseInt(y*scale)+'px');
   zone['Points'][index].y = y;
-  var Point = document.getElementById('zonePoly').points.getItem(index);
+  const Point = document.getElementById('zonePoly').points.getItem(index);
   Point.y = y;
   updateArea();
 }
@@ -427,13 +437,20 @@ function saveChanges(element) {
     if ( form.elements['newZone[Type]'].value == 'Privacy' ) {
       alert('Capture process for this monitor will be restarted for the Privacy zone changes to take effect.');
     }
+    for (var i = 0, length = monitors.length; i < length; i++) {
+      monitors[i].stop();
+    }
     return true;
   }
   return false;
 }
 
 function drawZonePoints() {
-  var imageFrame = document.getElementById('imageFrame');
+  var imageFrame = document.getElementById('imageFrame'+monitorId);
+  if (!imageFrame) {
+    console.log("No imageFrame for " + monitorId);
+    return;
+  }
   $j('.zonePoint').remove();
   var style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
   var padding_left = parseInt(style.paddingLeft);
@@ -457,10 +474,10 @@ function drawZonePoints() {
     div.mouseover(highlightOn.bind(i, i));
     div.mouseout(highlightOff.bind(i, i));
 
-    $j('#imageFrame').append(div);
+    $j(imageFrame).append(div);
 
     div.draggable({
-      'containment': imageFrame,
+      'containment': document.getElementById('imageFeed'+zone.MonitorId),
       'start': setActivePoint.bind(i, i),
       'stop': fixActivePoint.bind(i, i),
       'drag': updateActivePoint.bind(i, i)
@@ -652,7 +669,10 @@ function initPage() {
   }
   if ( el = cancelBtn[0] ) {
     el.onclick = function() {
-      window.location.reload(true);
+      for (var i = 0, length = monitors.length; i < length; i++) {
+        monitors[i].stop();
+      }
+      window.history.back();
     };
   }
 
@@ -661,11 +681,11 @@ function initPage() {
 
     // Start the fps and status updates. give a random delay so that we don't assault the server
     var delay = Math.round( (Math.random()+0.5)*statusRefreshTimeout );
-    monitors[i].setStreamScale('0');
+    monitors[i].setScale('0');
     monitors[i].start(delay);
   }
 
-  document.querySelectorAll('#imageFrame img').forEach(function(el) {
+  document.querySelectorAll('.imageFrame img').forEach(function(el) {
     el.addEventListener("load", imageLoadEvent, {passive: true});
   });
   window.addEventListener("resize", drawZonePoints, {passive: true});
@@ -691,7 +711,7 @@ function initPage() {
 function imageLoadEvent() {
   // We only need this event on the first image load to set dimensions.
   // Turn it off after it has been called.
-  document.querySelectorAll('#imageFrame img').forEach(function(el) {
+  document.querySelectorAll('.imageFrame img').forEach(function(el) {
     el.removeEventListener("load", imageLoadEvent, {passive: true});
   });
   drawZonePoints();
