@@ -33,20 +33,20 @@ if ( isset($_REQUEST['showZones']) ) {
   }
 }
 $widths = array( 
-  '0'  => 'auto',
-  '160' => '160px',
-  '320' => '320px',
-  '352' => '352px',
-  '640' => '640px',
-  '1280' => '1280px' );
+  'auto'  => 'auto',
+  '160px' => '160px',
+  '320px' => '320px',
+  '352px' => '352px',
+  '640px' => '640px',
+  '1280px' => '1280px' );
 
 $heights = array( 
-  '0'  => 'auto',
-  '240' => '240px',
-  '320' => '320px',
-  '480' => '480px',
-  '720' => '720px',
-  '1080' => '1080px',
+  'auto'  => 'auto',
+  '240px' => '240px',
+  '320px' => '320px',
+  '480px' => '480px',
+  '720px' => '720px',
+  '1080px' => '1080px',
 );
 
 
@@ -118,18 +118,20 @@ foreach ( $displayMonitors as &$row ) {
 
   if ( ZM_OPT_CONTROL && $row['ControlId'] && $row['Controllable'] )
     $showControl = true;
-  if ( ! isset($widths[$row['Width']]) ) {
-    $widths[$row['Width']] = $row['Width'].'px';
+  if ( ! isset($widths[$row['Width'].'px']) ) {
+    $widths[$row['Width'].'px'] = $row['Width'].'px';
   }
-  if ( ! isset($heights[$row['Height']]) ) {
-    $heights[$row['Height']] = $row['Height'].'px';
+  if ( ! isset($heights[$row['Height'].'px']) ) {
+    $heights[$row['Height'].'px'] = $row['Height'].'px';
   }
   $monitors[] = new ZM\Monitor($row);
 } # end foreach Monitor
 if (!$layout_id) {
   $default_layout = '';
   if (!$default_layout) {
-    if ((count($monitors) > 4) and (count($monitors)%4 == 0)) {
+    if ((count($monitors) > 5) and (count($monitors)%5 == 0)) {
+      $default_layout = '5 Wide';
+    } else if ((count($monitors) > 4) and (count($monitors)%4 == 0)) {
       $default_layout = '4 Wide';
     } else if (count($monitors)%3 == 0) {
       $default_layout = '3 Wide';
@@ -235,13 +237,10 @@ if ( canView('System') ) {
 <?php
 foreach ( $monitors as $monitor ) {
 ?>
-        <div
-          id="monitorFrame<?php echo $monitor->Id() ?>"
-          class="monitorFrame"
+          <div id="monitor<?php echo $monitor->Id() ?>" class="monitor idle"
           title="<?php echo $monitor->Id() . ' ' .$monitor->Name() ?>"
           style="<?php echo $options['width'] ? 'width:'.$options['width'].'px;':''?>"
-        >
-          <div id="monitor<?php echo $monitor->Id() ?>" class="monitor idle">
+>
             <div
               id="imageFeed<?php echo $monitor->Id() ?>"
               class="imageFeed"
@@ -253,7 +252,7 @@ foreach ( $monitors as $monitor ) {
   $monitor_options = $options;
   $monitor_options['width'] = $monitor_options['width']?$monitor_options['width'].'px' : null;
   $monitor_options['height'] = $monitor_options['height']?$monitor_options['height'].'px' : null;
-  $monitor_options['connkey'] = $monitor->connKey();
+  $monitor_options['mode'] = 'single';
 
   #ZM\Warning('Options: ' . print_r($monitor_options,true));
 
@@ -326,7 +325,6 @@ foreach ( array_reverse($zones) as $zone ) {
   }
 ?>
           </div>
-        </div>
 <?php
 } # end foreach monitor
 ?>
